@@ -15,6 +15,7 @@ import subprocess
 from collections.abc import Callable
 from datetime import datetime
 from pathlib import Path
+from typing import Any
 
 from rich.console import Console
 
@@ -148,7 +149,10 @@ class PhaseExecutor:
                 "PROJECT_DESCRIPTION": config.get("description", ""),
                 "PROJECT_MODE": config.get("mode", "personal"),
                 "PROJECT_VERSION": config.get("version", "0.1.0"),
+                "PROJECT_OWNER": config.get("author", "@user"),
                 "AUTHOR": config.get("author", "@user"),
+                "CONVERSATION_LANGUAGE": config.get("conversation_language", config.get("locale", "en")),
+                "CODEBASE_LANGUAGE": config.get("language", "generic"),
             }
             processor.set_context(context)
 
@@ -166,7 +170,7 @@ class PhaseExecutor:
     def execute_configuration_phase(
         self,
         project_path: Path,
-        config: dict[str, str | bool],
+        config: dict[str, str | bool | dict[Any, Any]],
         progress_callback: ProgressCallback | None = None,
     ) -> list[str]:
         """Phase 4: generate configuration.
@@ -184,9 +188,10 @@ class PhaseExecutor:
             "Phase 4: Generating configurations...", progress_callback
         )
 
-        # Attach version metadata (v0.3.1+)
-        config["moai_adk_version"] = __version__
-        config["optimized"] = False  # Default value
+        # Ensure project section exists and set defaults
+        if "project" not in config:
+            config["project"] = {}
+        config["project"]["optimized"] = False  # Default value
 
         # Write config.json
         config_path = project_path / ".moai" / "config.json"
